/**
 *@file input.h
 *
 * Helper functions for the anonymizing of vertices for the testing
 *    of evolution detection algorithms.
 *
 *@author James Thompson
 *Copyright James Thompson 2015
 *
 * This file is part of evo-robu. 

    evo-robu is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    evo-robu is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with evo-robu.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "input.h"

bool readIDs ( const string& filename, const string& dl, set < string >& v_id ){
  ifstream fin;
  openFileHarsh ( &fin, filename );

  vector < string > fields;
  while ( fline_tr ( &fin, &fields, dl ) ) {
    //Goes through each string on each line and adds it to the working set of IDs
    for ( unsigned int i = 0; i < fields.size(); i++ ){
      v_id.insert( fields[i] );
    } 
  }

  return true;
}

bool removeIDs ( const string& filename, const string& output_file, const set < string >& v_id ){
  ifstream fin; ofstream fout ( output_file.c_str() );
  openFileHarsh ( &fin, filename );
  
  vector < string > fields;
  
  while ( fline_tr ( &fin, &fields, " " ) ){              //Reads in community file
    for ( unsigned int i = 0; i < fields.size(); i++ ){
      if ( v_id.find ( fields[i] ) != v_id.end() ){       //Replaces ids with UNKNOWN
	fout << "UNKNOWN";
      } else {
	fout << fields[i];
      }

      if ( i != fields.size() - 1 )                      //Space delimited
	fout << " ";
      else
	fout << endl;
    }
  }
  
  fout.close();

  return true;
}
