/**
 *@file input.h
 *
 * Declarations for helper functions in anonymizing evolutions for
 *    robustness testing.
 *
 *@author James Thompson
 *Copyright James Thompson 2015
 *
 This file is part of evo-robu.

    evo-robu is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    evo-robu is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with evo-robu.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef RPI_INPUT
#define RPI_INPUT

#include <string>
#include <iostream>
#include <fstream>
#include <set>
#include <vector>

#include "../Libraries/Files/IOX.h"

using namespace std;

/**
 *@fn bool readIDs ( const string& filename, const string& dl, set < const string >& v_id )
 *
 *Compiles all vertex ids from a community file into one structure ( v_id )
 *
 *@param filename Community file to read from (One community per line)
 *@param dl Delimiter for the community file
 *@param v_id Set of current vertex IDs to add to
 *
 *@returns True. Intended for future error handling.
 **/
bool readIDs ( const string& filename, const string& dl, set < string >& v_id );

/**
 *@fn bool removeIDs ( const string& filename, const string& output_file, const set < string >& v_id )
 *
 *Opens the given file and copies the contents to output_file,                                                    
 * replacing any token that matches a string in v_id with                                                  
 * "UNKNOWN". 
 *
 *@param filename Community file to read
 *@param dl Delimiter for the community file
 *@param v_id Set of vertex IDs that should be replaced by 'UNKNOWN'
 **/
bool removeIDs ( const string& filename, const string& output_file, const set < string >& v_id );

#endif
